@@ -67,7 +67,7 @@ def command_name(cls):
     Unset = object()
     res = getattr(cls, 'command_cli_name', Unset)
     if res is not Unset:
-        from xoutil.six import string_types
+        from six import string_types
         if not isinstance(res, string_types):
             raise TypeError("Attribute 'command_cli_name' must be a string.")
     else:
